@@ -12,16 +12,11 @@
 
 Window::Window()
     : ui(new Ui::MainWindow())
-    , slc(new org::kde::ActivityManager::SLC(
-            "org.kde.ActivityManager",
-            "/SLC",
-            QDBusConnection::sessionBus(),
-            this))
+    , slc(new org::kde::ActivityManager::SLC("org.kde.ActivityManager", "/SLC", QDBusConnection::sessionBus(), this))
 {
     ui->setupUi(this);
 
-    connect(slc,  &org::kde::ActivityManager::SLC::focusChanged,
-            this, &Window::focusChanged);
+    connect(slc, &org::kde::ActivityManager::SLC::focusChanged, this, &Window::focusChanged);
 }
 
 Window::~Window()
@@ -29,12 +24,11 @@ Window::~Window()
     delete ui;
 }
 
-void Window::focusChanged(const QString &uri, const QString &mimetype,
-                          const QString &title)
+void Window::focusChanged(const QString &uri, const QString &mimetype, const QString &title)
 {
     Q_UNUSED(mimetype);
     Q_UNUSED(title);
     ui->textCurrentResource->setText(uri);
-
 }
 
+#include "moc_window.cpp"
